@@ -1,5 +1,6 @@
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
 
+import datetime
 import glob
 import hashlib
 import imp
@@ -10,6 +11,7 @@ import optparse
 import os
 import platform
 import re
+import signal
 import socket
 import subprocess
 import sys
@@ -209,13 +211,13 @@ class Dimensions(object):
         """
         new_dimensions = {'hostname': get_hostname()}
 
-        if dimensions is not None:
-            # Add or update any dimensions from the plugin itself
-            new_dimensions.update(dimensions.copy())
         default_dimensions = self.agent_config.get('dimensions', {})
         if default_dimensions:
             # Add or update any default dimensions that were set in the agent config file
             new_dimensions.update(default_dimensions)
+        if dimensions is not None:
+            # Add or update any dimensions from the plugin itself
+            new_dimensions.update(dimensions.copy())
         if instance:
             # Add or update any per instance dimensions that were set in the plugin config file
             new_dimensions.update(instance.get('dimensions', {}))
@@ -357,6 +359,21 @@ def get_uuid():
     return uuid.uuid5(uuid.NAMESPACE_DNS, platform.node() + str(uuid.getnode())).hex
 
 
+def timeout_command(command, timeout):
+    # call shell-command with timeout (in seconds).
+    # returns None if timeout or the command output.
+    start = datetime.datetime.now()
+    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    while process.poll() is None:
+        time.sleep(0.1)
+        now = datetime.datetime.now()
+        if (now - start).seconds > timeout:
+            os.kill(process.pid, signal.SIGKILL)
+            os.waitpid(-1, os.WNOHANG)
+            return None
+    return process.stdout.read()
+
+
 def get_os():
     "Human-friendly OS name"
     if sys.platform == 'darwin':
@@ -734,3 +751,11 @@ def get_sub_collection_warn():
     agent_config = config.get_config(sections='Main')
     sub_collection_warn = agent_config.get('sub_collection_warn')
     return sub_collection_warn
+
+
+def get_collector_restart_interval():
+    config = configuration.Config()
+    agent_config = config.get_config(sections='Main')
+    restart_interval = agent_config.get('collector_restart_interval')
+    restart_interval_in_sec = restart_interval * 60 * 60
+    return restart_interval_in_sec
