@@ -14,10 +14,32 @@ import monasca_setup.detection
 from monasca_setup.detection import find_process_cmdline
 from monasca_setup.detection import find_process_name
 from monasca_setup.detection import watch_process
+from monasca_setup.detection import watch_process_by_username
 
 log = logging.getLogger(__name__)
 
 
+class MonAgent(monasca_setup.detection.Plugin):
+    """Detect the Monsaca agent engine and setup some simple checks."""
+    def _detect(self):
+        """Run detection, set self.available True if the service is detected."""
+        self.available = True
+        agent_process_list = ['monasca-collector', 'monasca-forwarder', 'monasca-statsd']
+        for process in agent_process_list:
+            if find_process_cmdline(process) is None:
+                self.available = False
+                return
+
+    def build_config(self):
+        """Build the config as a Plugins object and return."""
+        log.info("\tEnabling the Monasca Agent process check")
+        return watch_process_by_username('mon-agent', 'monasca-agent', 'monitoring',
+                                         'monasca-agent')
+
+    def dependencies_installed(self):
+        return True
+
+
 class MonAPI(monasca_setup.detection.Plugin):
     """Detect mon_api and setup monitoring."""
     def _detect(self):
@@ -53,30 +75,62 @@ class MonAPI(monasca_setup.detection.Plugin):
             {
                 "name": "jvm.memory.total.max",
                 "path": "gauges/jvm.memory.total.max/value",
-                "type": "gauge"},
+                "type": "gauge"
+            },
             {
                 "name": "jvm.memory.total.used",
                 "path": "gauges/jvm.memory.total.used/value",
-                "type": "gauge"},
+                "type": "gauge"
+            },
             {
                 "name": "metrics.published",
                 "path": "meters/monasca.api.app.MetricService.metrics.published/count",
-                "type": "rate"},
-            {
-                "name": "raw-sql.time.avg",
-                "path": "timers/org.skife.jdbi.v2.DBI.raw-sql/mean",
-                "type": "gauge"},
-            {
-                "name": "raw-sql.time.max",
-                "path": "timers/org.skife.jdbi.v2.DBI.raw-sql/max",
-                "type": "gauge"},
+                "type": "rate"
+            }
         ]
-        config.merge(dropwizard_metrics('monitoring', 'monasca-api', 'http://localhost:8081/metrics', whitelist))
+
+        if not self._is_hibernate_on():
+            # if hibernate is not used, it is mysql with DBI
+            # for that case having below entries makes sense
+            log.debug('MonApi has not enabled Hibernate, adding DBI metrics')
+            whitelist.extend([
+                {
+                    "name": "raw-sql.time.avg",
+                    "path": "timers/org.skife.jdbi.v2.DBI.raw-sql/mean",
+                    "type": "gauge"
+                },
+                {
+                    "name": "raw-sql.time.max",
+                    "path": "timers/org.skife.jdbi.v2.DBI.raw-sql/max",
+                    "type": "gauge"
+                }
+            ])
+
+        config.merge(dropwizard_metrics('monitoring',
+                                        'monasca-api',
+                                        'http://localhost:8081/metrics',
+                                        whitelist))
+
         return config
 
     def dependencies_installed(self):
         return True
 
+    def _is_hibernate_on(self):
+        # check if api_config has been declared in __init__
+        # if not it means that configuration file was not found
+        # or monasca-api Python implementation is running
+
+        api_config = getattr(self, 'api_config', None)
+        if api_config is None:
+            return False
+
+        hibernate_cfg = self.api_config.get('hibernate', None)
+        if hibernate_cfg is None:
+            return False
+
+        return hibernate_cfg.get('supportEnabled', False)
+
 
 class MonNotification(monasca_setup.detection.Plugin):
     """Detect the Monsaca notification engine and setup some simple checks."""
@@ -88,7 +142,8 @@ class MonNotification(monasca_setup.detection.Plugin):
     def build_config(self):
         """Build the config as a Plugins object and return."""
         log.info("\tEnabling the Monasca Notification healthcheck")
-        return watch_process(['monasca-notification'], 'monitoring', 'monasca-notification', exact_match=False)
+        return watch_process_by_username('mon-notification', 'monasca-notification', 'monitoring',
+                                         'monasca-notification')
 
     def dependencies_installed(self):
         return True
@@ -209,7 +264,8 @@ class MonThresh(monasca_setup.detection.Plugin):
         config = monasca_setup.agent_config.Plugins()
         for process in ['backtype.storm.daemon.nimbus', 'backtype.storm.daemon.supervisor', 'backtype.storm.daemon.worker']:
             if find_process_cmdline(process) is not None:
-                config.merge(watch_process([process], 'monitoring', 'apache-storm', exact_match=False))
+                config.merge(watch_process([process], 'monitoring', 'apache-storm', exact_match=False, detailed=False))
+        config.merge(watch_process_by_username('storm', 'monasca-thresh', 'monitoring', 'apache-storm'))
         return config
 
     def dependencies_installed(self):
@@ -240,29 +296,6 @@ def dropwizard_metrics(service, component, url, whitelist):
     return config
 
 
-class MonVertica(monasca_setup.detection.Plugin):
-    """Detect Vertica and setup some simple checks."""
-
-    def _detect(self):
-        """Run detection, set self.available True if the service is detected.
-        """
-        if (find_process_name('vertica') is not None and find_process_name(
-                'spread') is not None):
-            self.available = True
-
-    def build_config(self):
-        """Build the config as a Plugins object and return."""
-        log.info("\tEnabling the Monasca Vertica check")
-        config = monasca_setup.agent_config.Plugins()
-        for process in ['vertica', 'spread']:
-            config.merge(watch_process([process], 'monitoring', process,
-                                       exact_match=False))
-        return config
-
-    def dependencies_installed(self):
-        return True
-
-
 class MonInfluxDB(monasca_setup.detection.Plugin):
     """Detect InfluxDB and setup some simple checks."""
 
