@@ -1,4 +1,4 @@
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
 
 """ Util functions to assist in detection.
 """
@@ -68,7 +68,7 @@ def find_addr_listening_on_port(port):
 
 
 def watch_process(search_strings, service=None, component=None,
-                  exact_match=True, detailed=False, process_name=None):
+                  exact_match=True, detailed=True, process_name=None):
     """Takes a list of process search strings and returns a Plugins object with the config set.
         This was built as a helper as many plugins setup process watching
     """
@@ -90,7 +90,7 @@ def watch_process(search_strings, service=None, component=None,
     return config
 
 
-def watch_process_by_username(username, process_name, service=None, component=None, detailed=False):
+def watch_process_by_username(username, process_name, service=None, component=None, detailed=True):
     """Takes a user and returns a Plugins object with the config set for a process check by user.
         This was built as a helper as many plugins setup process watching.
     """
@@ -109,7 +109,42 @@ def watch_process_by_username(username, process_name, service=None, component=No
     return config
 
 
-def service_api_check(name, url, pattern, service=None, component=None):
+def watch_file_size(directory_name, file_names, file_recursive,
+                    service=None, component=None):
+    """Takes a directory, a list of files, recursive flag and returns a
+        Plugins object with the config set.
+    """
+    config = agent_config.Plugins()
+    parameters = {'directory_name': directory_name,
+                  'file_names': file_names,
+                  'recursive': file_recursive}
+
+    dimensions = _get_dimensions(service, component)
+    if len(dimensions) > 0:
+        parameters['dimensions'] = dimensions
+
+    config['file_size'] = {'init_config': None,
+                           'instances': [parameters]}
+    return config
+
+
+def watch_directory(directory_name, service=None, component=None):
+    """Takes a directory name and returns a Plugins object with the config set.
+    """
+    config = agent_config.Plugins()
+    parameters = {'directory': directory_name}
+
+    dimensions = _get_dimensions(service, component)
+    if len(dimensions) > 0:
+        parameters['dimensions'] = dimensions
+
+    config['directory'] = {'init_config': None,
+                           'instances': [parameters]}
+    return config
+
+
+def service_api_check(name, url, pattern,
+                      use_keystone=True, service=None, component=None):
     """Setup a service api to be watched by the http_check plugin.
     """
     config = agent_config.Plugins()
@@ -117,7 +152,7 @@ def service_api_check(name, url, pattern, service=None, component=None):
                   'url': url,
                   'match_pattern': pattern,
                   'timeout': 10,
-                  'use_keystone': True}
+                  'use_keystone': use_keystone}
 
     dimensions = _get_dimensions(service, component)
     if len(dimensions) > 0:
@@ -125,7 +160,6 @@ def service_api_check(name, url, pattern, service=None, component=None):
 
     config['http_check'] = {'init_config': None,
                             'instances': [parameters]}
-
     return config
 
 
